@@ -250,9 +250,9 @@ impl VideoFetcher {
 
         let player_response = player_response.ok_or_else(|| Error::UnexpectedResponse(
             "Could not acquire the player response from the watch html!\n\
-            Note, that this is usually no problem and just happens due to a temporary fix to adapt \
-            to the new YouTube API.\n\
-            For more information checkout rustube#39 (https://github.com/DzenanJupic/rustube/issues/39).".into()
+            It looks like YouTube changed it's API again :-/\n\
+            If this not yet reported, it would be great if you could file an issue:
+            (https://github.com/DzenanJupic/rustube/issues/new?assignees=&labels=youtube-api-changed&template=youtube_api_changed.yml).".into()
         ))?;
 
         let video_info = VideoInfo {
@@ -482,21 +482,42 @@ fn parse_for_object<'a>(html: &'a str, regex: &Regex) -> crate::Result<&'a str>
 
 /// Deserializes the [`PalyerResponse`] which can be found in the watch html.
 #[inline]
+#[log_derive::logfn(Debug, fmt = "player response: {:?}")]
+#[log_derive::logfn_inputs(Trace, fmt = "player response json: {:?}")]
 fn deserialize_ytplayer_config(json: &str) -> crate::Result<PlayerResponse> {
     #[derive(Deserialize)]
     struct Args {
         player_response: PlayerResponse,
     }
-    #[derive(Deserialize)]
-    #[serde(untagged)]
-    enum PlayerConfig { Args { args: Args }, Response(PlayerResponse) }
 
-    Ok(
-        match serde_json::from_str::<PlayerConfig>(json)? {
-            PlayerConfig::Args { args } => args.player_response,
-            PlayerConfig::Response(pr) => pr
-        }
-    )
+    // There are multiple possible formats the PlayerResponse could be in. So we basically
+    // have an untagged enum here.
+    // ```rust
+    // #[derive(Deserialize)]
+    // #[serde(untagged)]
+    // enum PlayerConfig {
+    //     Args { args: Args },
+    //     Response(PlayerResponse)
+    // }
+    // ```
+    // The only problem with deserializing this enum is, that we don't get any information about
+    // the cause in case of a failed deserialization. That's why we do this manually here, so that
+    // the log contains information about the error cause.
+
+    let args_err = match serde_json::from_str::<PlayerResponse>(json) {
+        Ok(pr) => return Ok(pr),
+        Err(err) => err,
+    };
+
+    let pr_err = match serde_json::from_str::<Args>(json) {
+        Ok(args) => return Ok(args.player_response),
+        Err(err) => err,
+    };
+
+    Err(crate::Error::JsonDeserialization(serde::de::Error::custom(format_args!(
+        "data did not match any variant of untagged enum PlayerConfig:\n\tArgs:{}\n\tPlayerResponse:{}",
+        args_err, pr_err,
+    ))))
 }
 
 /// Extracts the JavaScript used for descrambling from the watch html.
