@@ -12,7 +12,7 @@ pub enum PlayabilityStatus {
     #[serde(rename_all = "camelCase")]
     Ok {
         playable_in_embed: bool,
-        miniplayer: MiniPlayer,
+        miniplayer: Option<MiniPlayer>,
         #[serde(default)]
         messages: Vec<String>,
         context_params: String,
@@ -22,7 +22,7 @@ pub enum PlayabilityStatus {
         #[serde(default)]
         messages: Vec<String>,
         reason: String,
-        error_screen: ErrorScreen,
+        error_screen: Option<ErrorScreen>,
         playable_in_embed: Option<bool>,
         miniplayer: Option<MiniPlayer>,
         context_params: String,
@@ -31,7 +31,7 @@ pub enum PlayabilityStatus {
     LoginRequired {
         #[serde(default)]
         messages: Vec<String>,
-        error_screen: ErrorScreen,
+        error_screen: Option<ErrorScreen>,
         desktop_legacy_age_gate_reason: Option<i64>,
         context_params: String,
     },
@@ -40,13 +40,13 @@ pub enum PlayabilityStatus {
         reason: String,
         playable_in_embed: bool,
         live_streamability: LiveStreamAbility,
-        miniplayer: MiniPlayer,
+        miniplayer: Option<MiniPlayer>,
         context_params: String,
     },
     #[serde(rename_all = "camelCase")]
     Error {
         reason: String,
-        error_screen: ErrorScreen,
+        error_screen: Option<ErrorScreen>,
         context_params: String,
     },
 }
